@@ -65,7 +65,7 @@ __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection"
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#serviceresourcetablescollection)
     """
 
@@ -92,7 +92,8 @@ class ServiceResourceTablesCollection(ResourceCollection):
 
 class Table(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#table)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#table)
     """
 
     attribute_definitions: List[Any]
@@ -118,15 +119,19 @@ class Table(Boto3ServiceResource):
     archival_summary: Dict[str, Any]
     name: str
 
-    def batch_writer(self, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
+    def batch_writer(self, *, overwrite_by_pkeys: List[str] = None) -> BatchWriter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        Create a batch writer object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablebatch_writer-method)
         """
 
     def delete(self) -> DeleteTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        The `DeleteTable` operation deletes a table and all of its items.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.delete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete-method)
         """
 
@@ -152,7 +157,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        Expected: Dict[str, ExpectedAttributeValueTypeDef] = None,
+        Expected: Dict[str, "ExpectedAttributeValueTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ReturnValues: ReturnValueType = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
@@ -180,13 +185,17 @@ class Table(Boto3ServiceResource):
         ] = None
     ) -> DeleteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        Deletes a single item in a table by primary key.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete_item-method)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        Returns a list of all the available sub-resources for this Resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_available_subresources-method)
         """
 
@@ -219,13 +228,19 @@ class Table(Boto3ServiceResource):
         ExpressionAttributeNames: Dict[str, str] = None
     ) -> GetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        The `GetItem` operation returns a set of attributes for the item with the given
+        primary key.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_item-method)
         """
 
     def load(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.load)
+        Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
+        Table resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableload-method)
         """
 
@@ -251,7 +266,7 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        Expected: Dict[str, ExpectedAttributeValueTypeDef] = None,
+        Expected: Dict[str, "ExpectedAttributeValueTypeDef"] = None,
         ReturnValues: ReturnValueType = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
@@ -279,7 +294,9 @@ class Table(Boto3ServiceResource):
         ] = None
     ) -> PutItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        Creates a new item, or replaces an old item with a new item.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.put_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableput_item-method)
         """
 
@@ -291,8 +308,8 @@ class Table(Boto3ServiceResource):
         AttributesToGet: List[str] = None,
         Limit: int = None,
         ConsistentRead: bool = None,
-        KeyConditions: Dict[str, ConditionTypeDef] = None,
-        QueryFilter: Dict[str, ConditionTypeDef] = None,
+        KeyConditions: Dict[str, "ConditionTypeDef"] = None,
+        QueryFilter: Dict[str, "ConditionTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ScanIndexForward: bool = None,
         ExclusiveStartKey: Dict[
@@ -340,13 +357,18 @@ class Table(Boto3ServiceResource):
         ] = None
     ) -> QueryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.query)
+        The `Query` operation finds items based on primary key values.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablequery-method)
         """
 
     def reload(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
+        Table resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablereload-method)
         """
 
@@ -357,7 +379,7 @@ class Table(Boto3ServiceResource):
         AttributesToGet: List[str] = None,
         Limit: int = None,
         Select: SelectType = None,
-        ScanFilter: Dict[str, ConditionTypeDef] = None,
+        ScanFilter: Dict[str, "ConditionTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ExclusiveStartKey: Dict[
             str,
@@ -406,7 +428,10 @@ class Table(Boto3ServiceResource):
         ConsistentRead: bool = None
     ) -> ScanOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        The `Scan` operation returns one or more items and item attributes by accessing
+        every item in a table or a secondary index.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablescan-method)
         """
 
@@ -416,13 +441,16 @@ class Table(Boto3ServiceResource):
         AttributeDefinitions: List["AttributeDefinitionTypeDef"] = None,
         BillingMode: BillingModeType = None,
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
-        GlobalSecondaryIndexUpdates: List[GlobalSecondaryIndexUpdateTypeDef] = None,
+        GlobalSecondaryIndexUpdates: List["GlobalSecondaryIndexUpdateTypeDef"] = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
-        SSESpecification: SSESpecificationTypeDef = None,
-        ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None
+        SSESpecification: "SSESpecificationTypeDef" = None,
+        ReplicaUpdates: List["ReplicationGroupUpdateTypeDef"] = None
     ) -> "_Table":
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.update)
+        Modifies the provisioned throughput settings, global secondary indexes, or
+        DynamoDB Streams settings for a given table.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate-method)
         """
 
@@ -448,8 +476,8 @@ class Table(Boto3ServiceResource):
                 None,
             ],
         ],
-        AttributeUpdates: Dict[str, AttributeValueUpdateTypeDef] = None,
-        Expected: Dict[str, ExpectedAttributeValueTypeDef] = None,
+        AttributeUpdates: Dict[str, "AttributeValueUpdateTypeDef"] = None,
+        Expected: Dict[str, "ExpectedAttributeValueTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ReturnValues: ReturnValueType = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
@@ -478,19 +506,26 @@ class Table(Boto3ServiceResource):
         ] = None
     ) -> UpdateItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        Edits an existing item's attributes, or adds a new item to the table if it does
+        not already exist.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.update_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate_item-method)
         """
 
     def wait_until_exists(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        Waits until this Table is exists.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_exists-method)
         """
 
     def wait_until_not_exists(self) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        Waits until this Table is not exists.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_not_exists-method)
         """
 
@@ -500,14 +535,17 @@ _Table = Table
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.ServiceResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
     """
 
     tables: ServiceResourceTablesCollection
 
     def Table(self, name: str) -> _Table:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        Creates a Table resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcetable-method)
         """
 
@@ -518,7 +556,10 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None
     ) -> BatchGetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        The `BatchGetItem` operation returns the attributes of one or more items from
+        one or more tables.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_get_item-method)
         """
 
@@ -530,7 +571,10 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None
     ) -> BatchWriteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        The `BatchWriteItem` operation puts or deletes multiple items in one or more
+        tables.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_write_item-method)
         """
 
@@ -540,21 +584,25 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         AttributeDefinitions: List["AttributeDefinitionTypeDef"],
         TableName: str,
         KeySchema: List["KeySchemaElementTypeDef"],
-        LocalSecondaryIndexes: List[LocalSecondaryIndexTypeDef] = None,
-        GlobalSecondaryIndexes: List[GlobalSecondaryIndexTypeDef] = None,
+        LocalSecondaryIndexes: List["LocalSecondaryIndexTypeDef"] = None,
+        GlobalSecondaryIndexes: List["GlobalSecondaryIndexTypeDef"] = None,
         BillingMode: BillingModeType = None,
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
-        SSESpecification: SSESpecificationTypeDef = None,
+        SSESpecification: "SSESpecificationTypeDef" = None,
         Tags: List["TagTypeDef"] = None
     ) -> _Table:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        The `CreateTable` operation adds a new table to your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcecreate_table-method)
         """
 
     def get_available_subresources(self) -> List[str]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        Returns a list of all the available sub-resources for this Resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourceget_available_subresources-method)
         """
